/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

import {dataRenderers, inputRenderers} from '../data_renderers/index';
import {getJsModule} from './modules';

export function getInputRendererById(id) {
	const inputRenderer = inputRenderers[id];

	if (!inputRenderer) {
		throw new Error(`No input renderer found with id "${id}"`);
	}

	return inputRenderer;
}

export function getDataRendererById(id) {
	const dataRenderer = dataRenderers[id];

	if (!dataRenderer) {
		throw new Error(`No data renderer found with id "${id}"`);
	}

	return dataRenderer;
}

export const fetchedContentRenderers = [];

export function getDataRendererByURL(url) {
	return new Promise((resolve, reject) => {
		const addedDataRenderer = fetchedContentRenderers.find(
			(contentRenderer) => contentRenderer.url === url
		);
		if (addedDataRenderer) {
			resolve(addedDataRenderer.component);
		}

		return getJsModule(url)
			.then((fetchedComponent) => {
				fetchedContentRenderers.push({
					component: fetchedComponent,
					url,
				});

				return resolve(fetchedComponent);
			})
			.catch(reject);
	});
}
